@@ -6,7 +6,7 @@
 
 package Lemonldap::NG::Manager::Build::Attributes;
 
-our $VERSION = '1.9.99_03';
+our $VERSION = '1.9.991_01';
 use strict;
 use Regexp::Common qw/URI/;
 
@@ -236,6 +236,10 @@ sub attributes {
             type          => 'longtext',
             documentation => 'Configuration update log',
         },
+        cfgVersion => {
+            type          => 'text',
+            documentation => 'Version of LLNG which build configuration',
+        },
         confirmFormMethod => {
             type => "select",
             select =>
@@ -261,7 +265,7 @@ sub attributes {
             default       => 'get',
             documentation => 'HTTP method for info page form',
         },
-        port       => { type => 'int', },
+        port => { type => 'int', documentation => 'Force port in redirection' },
         jsRedirect => {
             type          => 'boolOrExpr',
             default       => 0,
@@ -283,6 +287,7 @@ sub attributes {
             keyTest => qr/^\w+$/,
             test    => qr/^[a-zA-Z][a-zA-Z0-9]*(?:::[a-zA-Z][a-zA-Z0-9]*)*$/,
             msgFail => '__badPerlPackageName__',
+            documentation => 'Custom Nginx handler (deprecated)',
         },
         noAjaxHook => {
             default       => 0,
@@ -314,11 +319,12 @@ sub attributes {
             documentation => 'HTTP method for redirect page form',
         },
         reloadUrls => {
-            type    => 'keyTextContainer',
-            help    => 'configlocation.html#configuration_reload',
-            keyTest => qr/^$Regexp::Common::URI::RFC2396::host(?::\d+)?$/,
-            test    => $url,
-            msgFail => '__badUrl__'
+            type          => 'keyTextContainer',
+            help          => 'configlocation.html#configuration_reload',
+            keyTest       => qr/^$Regexp::Common::URI::RFC2396::host(?::\d+)?$/,
+            test          => $url,
+            msgFail       => '__badUrl__',
+            documentation => 'URL to call on reload',
         },
         staticPrefix => {
             type          => 'text',
@@ -329,6 +335,10 @@ sub attributes {
             default       => '; ',
             documentation => 'Separator for multiple values',
         },
+        stayConnected => {
+            type          => 'bool',
+            documentation => 'Enable StayConnected plugin',
+        },
 
         # Manager
         protection => {
@@ -371,9 +381,6 @@ sub attributes {
             documentation => 'Name of portal skin',
             select        => [
                 { k => 'bootstrap', v => 'Bootstrap' },
-                { k => 'pastel',    v => 'Pastel' },
-                { k => 'impact',    v => 'Impact' },
-                { k => 'dark',      v => 'Dark' },
             ],
         },
         portalSkinBackground => {
@@ -403,12 +410,13 @@ sub attributes {
             ],
         },
         portalSkinRules => {
-            type       => 'keyTextContainer',
-            help       => 'portalcustom.html',
-            keyTest    => $perlExpr,
-            keyMsgFail => '__badSkinRule__',
-            test       => qr/^\w+$/,
-            msgFail    => '__badValue__',
+            type          => 'keyTextContainer',
+            help          => 'portalcustom.html',
+            keyTest       => $perlExpr,
+            keyMsgFail    => '__badSkinRule__',
+            test          => qr/^\w+$/,
+            msgFail       => '__badValue__',
+            documentation => 'Rules to choose portal skin',
         },
 
         # Security
@@ -422,6 +430,11 @@ sub attributes {
             type          => 'bool',
             documentation => 'Enable token for forms',
         },
+        tokenUseGlobalStorage => {
+            default       => 0,
+            type          => 'bool',
+            documentation => 'Enable global token storage',
+        },
         cda => {
             default       => 0,
             type          => 'bool',
@@ -433,9 +446,10 @@ sub attributes {
             documentation => 'Check XSS',
         },
         grantSessionRules => {
-            type    => 'grantContainer',
-            keyTest => $perlExpr,
-            test    => sub { 1 },
+            type          => 'grantContainer',
+            keyTest       => $perlExpr,
+            test          => sub { 1 },
+            documentation => 'Rules to grant sessions',
         },
         hiddenAttributes => {
             type          => 'text',
@@ -453,7 +467,7 @@ sub attributes {
         },
         cspImg => {
             type          => 'text',
-            default       => "'self'",
+            default       => "'self' data:",
             documentation => 'Image source for Content-Security-Policy',
         },
         cspScript => {
@@ -463,7 +477,7 @@ sub attributes {
         },
         cspStyle => {
             type          => 'text',
-            default       => "'self'",
+            default       => "'self' 'unsafe-inline'",
             documentation => 'Style source for Content-Security-Policy',
         },
         cspConnect => {
@@ -504,8 +518,9 @@ sub attributes {
             default       => '[A-Z]{3}[a-z]{5}.\d{2}',
             documentation => 'Regular expression to create a random password',
         },
-        trustedDomains => { type => 'text', },
-        storePassword  => {
+        trustedDomains =>
+          { type => 'text', documentation => 'Trusted domains', },
+        storePassword => {
             default       => 0,
             type          => 'bool',
             documentation => 'Store password in session',
@@ -618,8 +633,9 @@ sub attributes {
         },
 
         # Cookies
-        cookieExpiration => { type => 'text', },
-        cookieName       => {
+        cookieExpiration =>
+          { type => 'text', documentation => 'Cookie expiration', },
+        cookieName => {
             type          => 'text',
             test          => qr/^[a-zA-Z][a-zA-Z0-9_-]*$/,
             msgFail       => '__badCookieName__',
@@ -654,15 +670,18 @@ sub attributes {
         oldNotifFormat => {
             type          => 'bool',
             default       => 0,
-            documentation => 'Use old XML format',
+            documentation => 'Use old XML format for notifications',
         },
         notificationWildcard => {
             type          => 'text',
             default       => 'allusers',
             documentation => 'Notification string to match all users',
         },
-        notificationXSLTfile => { type => 'text', },
-        notification         => {
+        notificationXSLTfile => {
+            type          => 'text',
+            documentation => 'Custom XSLT document for notifications',
+        },
+        notification => {
             default       => 0,
             type          => 'bool',
             documentation => 'Notification activation',
@@ -690,7 +709,7 @@ sub attributes {
             documentation => 'Captcha on login page',
         },
         captcha_mail_enabled => {
-            default       => 0,
+            default       => 1,
             type          => 'bool',
             documentation => 'Captcha on password reset page',
         },
@@ -752,9 +771,9 @@ sub attributes {
             documentation => 'Session backend module options',
         },
         localSessionStorage => {
-            type    => 'PerlModule',
-            default => 'Cache::FileCache',
-            , documentation => 'Sessions cache module',
+            type          => 'PerlModule',
+            default       => 'Cache::FileCache',
+            documentation => 'Sessions cache module',
         },
         localSessionStorageOptions => {
             type    => 'keyTextContainer',
@@ -769,12 +788,19 @@ sub attributes {
         },
 
         # Persistent storage
-        persistentStorage        => { type => 'PerlModule', },
-        persistentStorageOptions => { type => 'keyTextContainer', },
-        sessionDataToRemember    => {
-            type       => 'keyTextContainer',
-            keyTest    => qr/^[_a-zA-Z][a-zA-Z0-9_]*$/,
-            keyMsgFail => '__invalidSessionData__',
+        persistentStorage => {
+            type          => 'PerlModule',
+            documentation => 'Storage module for persistent sessions'
+        },
+        persistentStorageOptions => {
+            type          => 'keyTextContainer',
+            documentation => 'Options for persistent sessions storage module'
+        },
+        sessionDataToRemember => {
+            type          => 'keyTextContainer',
+            keyTest       => qr/^[_a-zA-Z][a-zA-Z0-9_]*$/,
+            keyMsgFail    => '__invalidSessionData__',
+            documentation => 'Data to remember in login history',
         },
 
         # SAML issuer
@@ -869,13 +895,15 @@ sub attributes {
         },
 
         # Mails
-        mailBody    => { type => 'longtext', },
+        mailBody =>
+          { type => 'longtext', documentation => 'Custom mail body', },
         mailCharset => {
             type          => 'text',
             default       => 'utf-8',
             documentation => 'Mail charset',
         },
-        mailConfirmBody    => { type => 'longtext', },
+        mailConfirmBody =>
+          { type => 'longtext', documentation => 'Custom confirm mail body', },
         mailConfirmSubject => {
             type          => 'text',
             documentation => 'Mail subject for reset confirmation',
@@ -885,7 +913,7 @@ sub attributes {
             default       => 'noreply@example.com',
             documentation => 'Sender email',
         },
-        mailReplyTo    => { type => 'text', },
+        mailReplyTo => { type => 'text', documentation => 'Reply-To address' },
         mailSessionKey => {
             type          => 'text',
             default       => 'mail',
@@ -911,8 +939,14 @@ sub attributes {
             test    => qr/^(?:$Regexp::Common::URI::RFC2396::host(?::\d+)?)?$/,
             documentation => 'SMTP Server',
         },
-        SMTPAuthUser => { type => 'text', },
-        SMTPAuthPass => { type => 'password', },
+        SMTPAuthUser => {
+            type          => 'text',
+            documentation => 'Login to use to send mails',
+        },
+        SMTPAuthPass => {
+            type          => 'password',
+            documentation => 'Password to use to send mails',
+        },
 
         # Registration
         registerConfirmSubject => {
@@ -922,10 +956,11 @@ sub attributes {
         registerDB => {
             type   => 'select',
             select => [
-                { k => 'AD',   v => 'Active Directory' },
-                { k => 'Demo', v => 'Demonstration' },
-                { k => 'LDAP', v => 'LDAP' },
-                { k => 'Null', v => 'None' },
+                { k => 'AD',     v => 'Active Directory' },
+                { k => 'Demo',   v => 'Demonstration' },
+                { k => 'LDAP',   v => 'LDAP' },
+                { k => 'Null',   v => 'None' },
+                { k => 'Custom', v => 'customModule' },
             ],
             default       => 'Null',
             documentation => 'Register module',
@@ -979,8 +1014,9 @@ sub attributes {
             documentation => 'Allow only one session per IP',
         },
         singleUserByIP => {
-            default => 0,
-            type    => 'bool',
+            default       => 0,
+            type          => 'bool',
+            documentation => 'Allow only one user per IP',
         },
         singleSessionUserByIP => {
             default       => 0,
@@ -1720,6 +1756,7 @@ sub attributes {
                 { k => 'Facebook',    v => 'Facebook' },
                 { k => 'Google',      v => 'Google' },
                 { k => 'LDAP',        v => 'LDAP' },
+                { k => 'PAM',         v => 'PAM' },
                 { k => 'Radius',      v => 'Radius' },
                 { k => 'REST',        v => 'REST' },
                 { k => 'SSL',         v => 'SSL' },
@@ -1737,6 +1774,7 @@ sub attributes {
                 { k => 'Remote',        v => 'Remote' },
                 { k => 'Slave',         v => 'Slave' },
                 { k => 'Null',          v => 'None' },
+                { k => 'Custom',        v => 'customModule' },
             ],
             default       => 'Demo',
             documentation => 'Authentication module',
@@ -1744,12 +1782,13 @@ sub attributes {
         userDB => {
             type   => 'select',
             select => [
-                { k => 'Same', v => 'Same' },
-                { k => 'AD',   v => 'Active Directory' },
-                { k => 'DBI',  v => 'Database (DBI)' },
-                { k => 'LDAP', v => 'LDAP' },
-                { k => 'REST', v => 'REST' },
-                { k => 'Null', v => 'None' },
+                { k => 'Same',   v => 'Same' },
+                { k => 'AD',     v => 'Active Directory' },
+                { k => 'DBI',    v => 'Database (DBI)' },
+                { k => 'LDAP',   v => 'LDAP' },
+                { k => 'REST',   v => 'REST' },
+                { k => 'Null',   v => 'None' },
+                { k => 'Custom', v => 'customModule' },
             ],
             default       => 'Same',
             documentation => 'User module',
@@ -1764,6 +1803,7 @@ sub attributes {
                 { k => 'LDAP',   v => 'LDAP' },
                 { k => 'REST',   v => 'REST' },
                 { k => 'Null',   v => 'None' },
+                { k => 'Custom', v => 'customModule' },
             ],
             default       => 'Demo',
             documentation => 'Password module',
@@ -1981,6 +2021,18 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
             keyMsgFail => '__badCasProxyId__',
         },
 
+        # PAM
+        pamAuthnLevel => {
+            type          => 'int',
+            default       => 2,
+            documentation => 'PAM authentication level',
+        },
+        pamService => {
+            type          => 'text',
+            default       => 'login',
+            documentation => 'PAM service',
+        },
+
         # Radius
         radiusAuthnLevel => {
             type          => 'int',
@@ -2180,6 +2232,7 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
                     { k => 'Facebook',      v => 'Facebook' },
                     { k => 'Google',        v => 'Google' },
                     { k => 'LDAP',          v => 'LDAP' },
+                    { k => 'PAM',           v => 'PAM' },
                     { k => 'Null',          v => 'None' },
                     { k => 'OpenID',        v => 'OpenID' },
                     { k => 'OpenIDConnect', v => 'OpenID Connect' },
@@ -2192,7 +2245,8 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
                     { k => 'SSL',           v => 'SSL' },
                     { k => 'Twitter',       v => 'Twitter' },
                     { k => 'WebID',         v => 'WebID' },
-                    { k => 'Yubikey',       v => 'Yubikey' }
+                    { k => 'Yubikey',       v => 'Yubikey' },
+                    { k => 'Custom',        v => 'customModule' },
                 ],
                 [
                     { k => 'AD',            v => 'Active Directory' },
@@ -2209,15 +2263,17 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
                     { k => 'Remote',        v => 'Remote' },
                     { k => 'SAML',          v => 'SAML v2' },
                     { k => 'Slave',         v => 'Slave' },
-                    { k => 'WebID',         v => 'WebID' }
+                    { k => 'WebID',         v => 'WebID' },
+                    { k => 'Custom',        v => 'customModule' },
                 ],
                 [
-                    { k => 'AD',   v => 'Active Directory' },
-                    { k => 'DBI',  v => 'Database (DBI)' },
-                    { k => 'Demo', v => 'Demo' },
-                    { k => 'LDAP', v => 'LDAP' },
-                    { k => 'REST', v => 'REST' },
-                    { k => 'Null', v => 'None' }
+                    { k => 'AD',     v => 'Active Directory' },
+                    { k => 'DBI',    v => 'Database (DBI)' },
+                    { k => 'Demo',   v => 'Demo' },
+                    { k => 'LDAP',   v => 'LDAP' },
+                    { k => 'REST',   v => 'REST' },
+                    { k => 'Null',   v => 'None' },
+                    { k => 'Custom', v => 'customModule' },
                 ]
             ],
         },
@@ -2239,6 +2295,7 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
                 { k => 'Facebook', v => 'Facebook' },
                 { k => 'Google',   v => 'Google' },
                 { k => 'LDAP',     v => 'LDAP' },
+                { k => 'PAM',      v => 'PAM' },
                 { k => 'Radius',   v => 'Radius' },
                 { k => 'REST',     v => 'REST' },
                 { k => 'SSL',      v => 'SSL' },
@@ -2254,6 +2311,7 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
                 { k => 'Remote',        v => 'Remote' },
                 { k => 'Slave',         v => 'Slave' },
                 { k => 'Null',          v => 'None' },
+                { k => 'Custom',        v => 'customModule' },
             ],
         },
 
@@ -2271,6 +2329,28 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
             documentation => 'Yubikey public ID size',
         },
 
+        # Custom auth modules
+        customAuth => {
+            type          => 'text',
+            documentation => 'Custom auth module',
+        },
+        customUserDB => {
+            type          => 'text',
+            documentation => 'Custom user DB module',
+        },
+        customPassword => {
+            type          => 'text',
+            documentation => 'Custom password module',
+        },
+        customRegister => {
+            type          => 'text',
+            documentation => 'Custom register module',
+        },
+        customAddParams => {
+            type          => 'keyTextContainer',
+            documentation => 'Custom additional parameters',
+        },
+
         # OpenID Connect auth params
         oidcAuthnLevel => {
             type          => 'int',
@@ -2329,6 +2409,16 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
             default       => 'checksession.html',
             documentation => 'OpenID Connect check session iframe',
         },
+        oidcServiceMetaDataBackChannelURI => {
+            type          => 'text',
+            default       => 'blogout',
+            documentation => 'OpenID Connect Front-Channel logout endpoint',
+        },
+        oidcServiceMetaDataFrontChannelURI => {
+            type          => 'text',
+            default       => 'flogout',
+            documentation => 'OpenID Connect Front-Channel logout endpoint',
+        },
         oidcServiceMetaDataAuthnContext => {
             type    => 'keyTextContainer',
             keyTest => qr/\w/,
@@ -2471,7 +2561,23 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
           { type => 'keyTextContainer', default => {} },
         oidcRPMetaDataOptionsBypassConsent =>
           { type => 'bool', help => 'openidconnectclaims.html', default => 0 },
-
+        oidcRPMetaDataOptionsLogoutUrl => {
+            type          => 'url',
+            documentation => 'Logout URL',
+        },
+        oidcRPMetaDataOptionsLogoutType => {
+            type   => 'select',
+            select => [
+                { k => 'front', v => 'Front Channel' },
+                { k => 'back',  v => 'Back Channel' },
+            ],
+            default       => 'front',
+            documentation => 'Logout type',
+        },
+        oidcRPMetaDataOptionsLogoutSessionRequired => {
+            type          => 'bool',
+            documentation => 'Session required for logout',
+        },
     };
 }
 
