@@ -14,7 +14,7 @@
 
 package Lemonldap::NG::Manager::Build::CTrees;
 
-our $VERSION = '1.9.99_03';
+our $VERSION = '1.9.991_01';
 
 sub cTrees {
     return {
@@ -199,6 +199,15 @@ sub cTrees {
                     'oidcRPMetaDataOptionsAccessTokenExpiration',
                     'oidcRPMetaDataOptionsRedirectUris',
                     'oidcRPMetaDataOptionsBypassConsent',
+                    {
+                        title => 'logout',
+                        form  => 'simpleInputContainer',
+                        nodes => [
+                            'oidcRPMetaDataOptionsLogoutUrl',
+                            'oidcRPMetaDataOptionsLogoutType',
+                            'oidcRPMetaDataOptionsLogoutSessionRequired',
+                        ]
+                    },
                 ]
             },
             'oidcRPMetaDataOptionsExtraClaims',
