@@ -13,7 +13,7 @@
 
 package Lemonldap::NG::Manager::Build::Tree;
 
-our $VERSION = '1.9.99_03';
+our $VERSION = '1.9.991_01';
 
 # TODO: Missing:
 #  * activeTimer
@@ -287,6 +287,12 @@ sub tree {
                                 'proxyUseSoap'
                             ]
                         },
+                        {
+                            title => 'pamParams',
+                            help  => 'authpam.html',
+                            form  => 'simpleInputContainer',
+                            nodes => [ 'pamService', 'pamAuthnLevel', ]
+                        },
                         {
                             title => 'radiusParams',
                             help  => 'authradius.html',
@@ -356,6 +362,16 @@ sub tree {
                                 'yubikeySecretKey',  'yubikeyPublicIDSize'
                             ]
                         },
+                        {
+                            title => 'customParams',
+                            help  => 'authcustom.html',
+                            form  => 'simpleInputContainer',
+                            nodes => [
+                                'customAuth',     'customUserDB',
+                                'customPassword', 'customRegister',
+                                'customAddParams',
+                            ]
+                        },
                     ],
                     'nodes_filter' => 'authParams'
                 },
@@ -501,6 +517,7 @@ sub tree {
                 {
                     title => 'plugins',
                     nodes => [
+                        'stayConnected',
                         'portalStatus',
                         {
                             title => 'portalServers',
@@ -627,6 +644,7 @@ sub tree {
                                 },
                                 'requireToken',
                                 'formTimeout',
+                                'tokenUseGlobalStorage',
                             ]
                         },
                         {
@@ -844,6 +862,8 @@ sub tree {
                         'oidcServiceMetaDataRegistrationURI',
                         'oidcServiceMetaDataEndSessionURI',
                         'oidcServiceMetaDataCheckSessionURI',
+                        'oidcServiceMetaDataFrontChannelURI',
+                        'oidcServiceMetaDataBackChannelURI',
                     ]
                 },
                 'oidcServiceMetaDataAuthnContext',
