@@ -1,6 +1,6 @@
 package Lemonldap::NG::Manager::Conf::Zero;
 
-our $VERSION = '1.9.99_03';
+our $VERSION = '1.9.991_01';
 
 sub zeroConf {
     my ( $domain, $sessionDir, $persistentSessionDir, $notificationDir ) = @_;
@@ -108,7 +108,7 @@ sub zeroConf {
         },
         'macros' => {
             '_whatToTrace' =>
-              '$_auth eq \'SAML\' ? "$_user\\@$_idpConfKey" : "$_user"'
+'$_auth eq \'SAML\' ? "$_user\\@$_idpConfKey" : $_auth eq \'OpenIDConnect\' ? "$_user\\@$_oidcConnectedRP" : "$_user"'
         },
         'notificationStorageOptions' => {
             'dirName' => $notificationDir
@@ -166,6 +166,7 @@ sub zeroConf {
         'securedCookie' => 0,
         'cookieName'    => 'lemonldap',
         'cfgAuthor'     => 'The LemonLDAP::NG team',
+        'cfgVersion'    => $VERSION,
         'exportedVars'  => {
             'UA' => 'HTTP_USER_AGENT'
         },
